@@ -4,7 +4,7 @@ __author__ = 'Altertech, https://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2020 Altertech'
 __license__ = 'Apache License 2.0'
 
-__version__ = '0.0.9'
+__version__ = '0.0.12'
 
 import sys
 import argparse
@@ -15,7 +15,7 @@ import jsonschema
 import yaml
 
 from time import perf_counter, sleep
-from .outputs import OUTPUT_METHODS, oprint
+from .outputs import OUTPUT_METHODS, eprint, print_trace
 from queue import Queue
 
 q = Queue()
@@ -29,14 +29,14 @@ processor_maps = []
 
 DEFAULT_TIMEOUT = 5
 DEFAULT_FREQUENCY = 1
-DEFAULT_BEACON_FREQUENCY = 0
+DEFAULT_BEACON_INTERVAL = 0
 
 last_pull_time = 0
 
 config = {
     'timeout': DEFAULT_TIMEOUT,
     'freq': DEFAULT_FREQUENCY,
-    'beacon': DEFAULT_BEACON_FREQUENCY,
+    'beacon': DEFAULT_BEACON_INTERVAL,
     'output': None
 }
 
@@ -111,9 +111,7 @@ def _t_beacon(fn, interval):
             fn()
             next_beacon += interval
     except:
-        import traceback
-        oprint('beacon error', file=sys.stderr)
-        oprint(traceback.format_exc())
+        print_trace()
 
 
 def _t_processor():
@@ -126,8 +124,7 @@ def _t_processor():
             for fn in prc_map:
                 fn(data)
     except:
-        import traceback
-        oprint(traceback.format_exc(), file=sys.stderr)
+        print_trace()
 
 
 def do(loop=False):
@@ -151,7 +148,7 @@ def do(loop=False):
             if ts > 0:
                 sleep(ts)
             else:
-                oprint('WARNING: main loop timeout', file=sys.stderr)
+                eprint('WARNING: main loop timeout')
         next_iter += interval
 
     if loop:
@@ -228,8 +225,7 @@ def main():
                 break
             except:
                 if a.restart and a.loop:
-                    import traceback
-                    oprint(traceback.format_exc(), file=sys.stderr)
+                    print_trace()
                     sleep(config['interval'])
                 else:
                     raise
